#
# spec file for package ast-grep
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ast-grep
Version:        0.31.1
Release:        1.1
Summary:        A CLI tool for code structural search, lint and rewriting
License:        MIT
URL:            https://ast-grep.github.io/
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  gcc-c++

%description
ast-grep(sg) is a CLI tool for code structural search, lint, and rewriting.

%prep
%autosetup -p1 -a1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build} --locked

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}

%files
%{_bindir}/%{name}
%license LICENSE
%doc CHANGELOG.md README.md

%changelog
* Mon Dec 16 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.31.1:
  * feat: update tree-sitter dependency to 0.24.4 91a2b46
  * fix(deps): update dependency @swc/core to v1.10.0 526648b
  * fix: fix new clippy error ebfcbcd
* Mon Dec 16 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.31.0:
  * feat: only scan rule senstive files #1635
  * feat: better error handling for dynamic lib loading #1631
  * Breaking change: feat: support character based column number #1594
  * Breaking change: refactor: expose new struct Position for abstracting column b87dad7
  * refactor: Use the utf-corrected row and column methods for the range matcher 2b30f56
  * feat: Add support for range matcher 4fb2c52
* Wed Nov 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.30.1:
  * fix: fix --config=config.yml arg parse #1617
  * fix: update python version #1614
  * fix(deps): update dependency @swc/core to v1.9.3 63c1c8d
  * chore: revert pyo3 2022f38
  * feat: add rule entity inspection c569ec7
* Wed Nov 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.30.0:
  * Breaking change: feat: semi-structured tracing output #1574
  * fix: error=unused-suppression should change exit code #1585
  * refactor: move stdErr into inspect mod #1575
  * infra: switch to llvm-cov #1570
  * Breaking change: refactor: rename --tracing to --inspect 105945e
  * Breaking change: refactor: remove --json format for tracing ed05be4
  * Breaking change: fix: remove builtin dart support cd25a62
  * Breaking change: fix: report unused suppression always 893df63
  * fix(deps): update babel monorepo b8803ce
* Wed Oct 30 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.29.0:
  * feat: support override severity of unused-suppression #1556
  * feat: unify configuration reading #1557
  * feat: unify configuration #1557
  * refactor: improve file config handling #1553
  * refactor: revamp configuration file discovering and custom language registration #1553
  * feat(scan): support context, before/after flags #1549
  * feat: add RuleOverwrite to override rule severity from CLI #1061
  * Breaking change: feat: support --config in sg new cfe472f
  * feat: add rule overwrite impl fb4ac07
  * fix(deps): update dependency @swc/core to v1.7.36 c11fd89
* Sun Oct 20 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.28.1:
  * feat: report unused suppression #1346
  * feat: make number of threads configurable #1498
  * doc: add bug report yaml #1462
  * refactor: rename tracing f83dbe9
  * fix: fix bug report bug agains 61921f7
  * fix(deps): update dependency @babel/core to v7.25.8 cf06185
* Mon Oct  7 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.28.0:
  * feat: TypeScript types for Rules in NAPI #1038
  * feat:support glob path match in CLI #1062
  * refactor: move input/output args to standalone file 3d937cb
  * refactor: move worker outside of utils 84ea621
  * fix(deps): update babel monorepo to v7.25.7 b989f05
* Mon Sep 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.27.3:
  * feat: add prettified pattern debug 70d33b5
  * fix(deps): update rust crate pyo3 to v0.22.3 683e398
  * test: add test for CST a79f13f
* Mon Sep 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.27.2:
  * feat: add follow symbolic links option to CLI #1461
  * fix(deps): update dependency @swc/core to v1.7.26 e0b437d
  * fix(deps): update dependency @swc/core to v1.7.24 657bc4e
  * chore(deps): update dependency typescript to v5.6.2 c55a404
* Mon Sep  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.27.1:
  * fix: create .gitkeep file in new dirs #1273
  * fix: fix unwrap error for unfound dir #1456
  * fix(deps): update dependency @swc/core to v1.7.23 5fd4101
  * chore(deps): update dependency @types/node to v20.16.5 294e402
  * fix: improve error message d46df6a
* Mon Sep  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.27.0:
  * feat: support YAML language #1436
  * fix(deps): update dependency @swc/core to v1.7.22 c577761
  * fix(deps): update dependency @swc/core to v1.7.21 4b0e594
  * feat: add rule config potential kind test def5b21
* Mon Aug 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.26.3:
  * fix: fix wrong transformation indentation #1405
  * fix: compare only kind for unnamed nodes #1419
  * fix(deps): update dependency @swc/core to v1.7.18 9ecb02c
  * fix(deps): update dependency @swc/core to v1.7.14 459d20a
  * test: add test for transformation indentation e0bfaf2
* Tue Aug 20 2024 Holger Rauch <holger.rauch@posteo.de>
- Added ppc64le to the list of architectures (_constraints)
* Tue Aug 20 2024 Holger Rauch <holger.rauch@posteo.de>
- Increased memory to 8 GB for s390x (_constraints)
* Mon Aug 19 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.26.2:
  * fix: readopt matched metavar in napi #1380
  * chore: update napi definition 07e084a
  * fix(deps): update dependency @swc/core to v1.7.11 835b06f
  * fix(deps): update dependency @swc/core to v1.7.10 d7a3820
* Sat Aug 10 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.26.1:
  * feat: support dynamic language in pyo3 #1143
  * test: add test for load dynamic lang in python 236f4ab
  * feat: add py_lang registration function 43e74e7
  * feat: add pytype for register language 8b660cf
* Thu Aug  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.26.0:
  * feat: Additional impls for language types #1379
  * feat: append note to error message if available #1384
  * fix: LSP should skip files outside the workspace root #1382
  * fix(deps): update dependency @babel/core to v7.25.2 3b0be88
  * refactor: split two macros b760eb8
  * refactor: simplify visitor 5ae03ae
* Wed Aug  7 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.25.7:
  * feat: add charCount to split lines #1381
  * chore(deps): update dependency @types/node to v20.14.14 bca7e7b
  * fix(deps): update rust crate clap to v4.5.13 c143464
  * fix(deps): update rust crate toml_edit to v0.22.20 170da4c
* Mon Aug  5 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.25.6:
  * feat: add --selector in sg run #1378
  * fix: fix clippy new complaints a4cc793
  * fix(deps): update dependency @swc/core to v1.7.5 d3ee100
  * chore(deps): update rust crate tree-sitter to v0.22.2 93d684a
* Fri Aug  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.25.5:
  * feat: support using transform in rule message #1366
  * test: add test for skipping multiple ellipsis #1365
  * feat: Support ast-grep-ignore comment on same line as violation #1347
  * Revert "feat: add wasm engine support" 78b1633
  * feat: add wasm engine support ff77914
  * refactor: remove old find/scan 58a3646
* Fri Jul 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.25.4:
  * feat: support sql experimentally #1300
  * feat: consistent file path for search by removing ./ prefix #1343
  * feat: allow multiple tests in a single YAML file #1344
  * refactor: use HarnessBuilder c41ffa8
  * refactor: move out some files dfa38f2
  * test: add test for deserde tests 76796e4
* Tue Jul 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.25.3:
  * feat: support custom language injection #1309
  * feat: register embedded language 416e28e
  * fix(deps): update dependency @babel/core to v7.24.9 8c5dd00
  * fix(deps): update dependency @swc/core to v1.7.0 61f6a14
* Fri Jul 19 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.25.2:
  * fix: only present code action when there are truly fixable diagnostic #1327
  * refactor: move some function out of lsp 1e6b477
  * fix: use fix in data for fix all command d358d45
  * fix: update fix all lsp b760b9b
* Mon Jul 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.25.1:
  * fix: make config file work outside of workspace root #1326
  * fix: fix napi musl bde7f34
  * fix: debug napi 2d87fc5
* Mon Jul 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.25.0:
  * Fix Python 3.10 macOS ast-grep-py build #1315
  * feat: support multiple doc in scan #1310
  * fix: fix testing #1305
  * feat: support searching injected code in specified lang #1307
  * feat: improve HTML language extraction for ts/scss #1301
  * fix: use relative path in lsp #1272
  * fix: use match info in lsp message #1271
  * feat: support arm64 musl #1227
  * fix(deps): update dependency @babel/core to v7.24.8 624aa70
  * feat: support multiple regions in run 07ef11f
  * refactor: move Html out 4a0c177
* Thu Jun 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.24.1:
  * fix: skip missing node in pattern #1256
  * doc: add cli help text for debug format 1754382
* Mon Jun 24 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.24.0:
  * feat: add debug ast and cst #1218
  * feat: add strictness in PyO3 #1246
  * feat: add strictness flag in cli #1243
  * test: add test for different strictness #1241
  * feat: add strictness to YAML #1239
  * Breaking change: fix: update API for fix 4971ac2
  * Breaking change: fix: change deletedLength to endPos in napi c0e9a65
  * feat: add colorized output 22f279c
* Mon Jun 24 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.23.1:
  * fix: all should not pollute env #1225
  * Breaking change: feat: use new pattern struct f219b43
  * refactor: move match_node impl out 27c918a
  * refactor: factor out match_ellipsis logic 407d2a8
* Tue Jun 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.23.0:
  * feat: add typings for pyo3 #676
  * refactor: remove unused old code 3ffd1d9
  * fix(deps): update babel monorepo to v7.24.7 b4aebaf
  * refactor: add new abstraction for match_tree 079bc7d
* Wed Jun  5 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.22.6:
  * fix: add Edit to export list #1186
  * feat: add modify edit range feature in pyo3 1e31253
  * test: add test for modifying edit 7044811
  * fix: addClass Edit in pyo3 d81c6c3
* Mon Jun  3 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.22.5:
  * feat: support all languages in napi #1170
  * Breaking change: refactor: rename Frontend Language to Lang c582c16
  * refactor: move find files operations to standalone files 8ebb888
  * feat: support more languages in napi 19e3baa
* Mon May 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.22.4:
  * feat: use var defined in utils in transform/fix #1155
  * fix: fix pattern polluting env #1164
  * test: add python fix test #1161
  * feat: add fix related feature to pyo3 #1159
  * test: add test for napi test #1160
  * feat: add commit_fix and fix to napi #1158
  * fix(deps): update babel monorepo to v7.24.6 0898b55
  * fix(deps): update dependency @swc/core to v1.5.7 9beda6e
  * feat: add edit/fix sketch 6817854
* Mon May 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.22.3:
  * fix: fix napi test #1140
  * fix: use dumb implementation for web-tree-sitter 5cb7052
  * chore: fix asset names 70cef40
  * fix af20be8
* Mon May 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.22.2:
  * fix: fix releases 3a6e553
  * fix: fix efaa1ca
  * fix: debug e39fd12
* Mon May 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.22.1:
  * feat(language): Add support for Haskell via tree-sitter-haskell #1128
  * fix: add ast-grep to release #1130
  * fix(deps): update dependency @swc/core to v1.5.5 31428dd
  * fix(deps): update dependency tree-sitter-typescript to v0.21.1 188525d
  * chore(deps): update dependency @types/node to v20.12.11 3fe7780
* Mon May 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.22.0:
  * test: add string test case back in Rust #1060
  * chore: bump tree-sitter version 5b45bd7
  * fix: update wasm crate ce9acba
  * fix: update ts deps 3a67b6b
* Tue May  7 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.21.4:
  * fix: build from source #1125
  * doc: update how to install via cargo #1118
  * feat: report undefined util rules #1106
  * Breaking change: feat: separate RuleCoreError and RuleConfigError d96efa9
  * refactor: move Transformation into a standalone module b51cc95
  * fix(deps): update dependency @babel/core to v7.24.5 77ea8bd
* Fri May  3 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.21.3:
  * feat: make pattern more permissive #1087
  * refactor: further simplify test case 8188473
  * refactor: make rewrite test simplier 5a754ef
  * test: add test for contextual pattern defined var 2d6bae8
* Thu May  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.21.2:
  * feat: Allow to use meta variable captured outside of rewrite rule inside the rewriter #1072
  * refactor: move rule_core test out of rule_core 1e8af4c
  * feat: move check variable usage out to a standalone file f086d10
  * refactor: move check var around cfe3529
* Mon Apr 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.21.1:
  * feat: find defined vars in utils cbc6534
  * fix: add referent rule stack overflow test case f7f24e1
  * feat: add utils defined vars 59001eb
* Mon Apr 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.21.0:
  * feat: report unused rewriters #1064
  * feat: report undefined error in fix #1070
  * feat: define the resolution order of meta variables #1068
  * feat: export used meta-var in transform #1069
  * feat: export meta variables defined in transform #1066
  * feat: export meta variables defined in constraints/rules #1067
  * test: add test for Pattern::defined_vars method #1065
  * feat: analyze meta variables defined in pattern #1065
  * feat: add field id Error for relational rule #1059
  * feat: support rewrtier check in sub-rule eb4c47c
  * test: add undefined rewriter test d56ad74
  * feat: add used_vars in TemplateFix 641d3b4
* Thu Apr 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.5:
  * fix: add parse global util error 2482a86
  * fix: ignore test 6c2cd46
* Mon Apr  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.4:
  * fix: fix new deprecation note of Rust 2024 a70565e
  * fix: fix quickfix fef3dfc
  * fix: better fix message e0b5875
* Mon Apr  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.3:
  * feat(lsp): run "source.fixAll.ast-grep" onsave #1021
  * test: move the integration-test to test folder f2ff77a
  * chore: cargo update 83394e9
  * refactor: move logging and io out of on_apply_all_fix cd79cda
* Thu Mar 28 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.2:
  * feat: make test --update-all not report error #771
  * fix: fix update cases f8132a4
  * refactor: less indentation for interactive reporter 203bd35
  * feat: improve accept 441a548
* Mon Mar 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.1:
  * feat: respect suppression in lsp #1019
* Mon Mar 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.0:
  * test: add test for error suppression in scan #1007
  * refactor: merge CombinedScan::scan and CombinedScan::diff #1011
  * feat: report error count instead of file count #1009
  * feat: suppress specific rule #1005
  * fix: skip suppressed error #1006
  * feat: support error/warning suppression #446
  * fix(deps): update babel monorepo da9a938
  * fix(deps): update dependency @swc/core to v1.4.8 d81365a
  * feat: add more states for rule suppression 41a058c
* Mon Mar 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.4:
  * LSP default message for diagnostics #970
  * feat: Add error messaging for rule file parsing failures #968
  * feat: add html testing and tweak html #977
  * fix(deps): update dependency @babel/core to v7.24.0 a14741d
  * fix(deps): update dependency @swc/core to v1.4.6 4a397f4
  * fix(deps): update rust crate pyo3 to 0.20.3 23653c2
* Mon Feb 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.3:
  * fix(deps): update dependency @swc/core to v1.4.2 67450cb
  * refactor: move rewriters to SerializableRuleConfig d98c062
  * fix(deps): update rust crate inquire to 0.7.0 86ec845
* Fri Feb 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.2:
  * fix: improve expando char replacement #883
  * feat(napi): add support for napi linux x64 musl c4d7902
  * fix: fix wrong spacing matching 0e8b4f0
  * Update README.md 9636a1a
* Tue Feb 20 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.1:
  * fix: avoid input stream when --update-all #943
  * fix: update cargo lock 8a893e7
  * fix(deps): update dependency @swc/core to v1.4.1 d18fd70
  * chore(deps): update dependency @types/node to v20.11.19 40d3fa0
* Thu Feb 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.0:
  * Breaking change: refactor: remove unused type generic 9b13d41
  * Breaking change: fix: update pyo3 test ff10e81
  * fix: fix parallel thread output be230ca
* Thu Feb  1 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.1:
  * Breaking change: refactor: use more concise name 6a4a17c
* Wed Jan 31 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.0:
  * Breaking change: refactor: remove IndentSensitive trait #868
  * feat: add support for rewriters #855
  * Breaking change: refactor: rename RuleWithConstraints to RuleCore #862
  * feat: move fix to SerializableRuleCore #859
  * Breaking change: refactor: remove MetaVarMatchers beb6f50
  * Breaking change: feat: move fixer to RuleCore 8a43a26
  * Breaking change: refactor: move language out of SerializableRuleCore c5e0dc8
  * Breaking change: refactor: remove Content generic from Fixer 87bbf93
  * Breaking change: feat: improve get_fixer signature e629e0f
  * Breaking change: refactor: make TemplateFix non-generic 0f462a5
  * feat: migrate constraints to Rule 230ee9c
  * refactor: move SerializableRuleCore to rule_core mod 3a303c1
* Sat Jan 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.17.1:
  * feat: respect user's language extension option #848
* Fri Jan 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Breaking change: feat: change get_fixer to return Fixer 07c5363
  * feat: add modify_range for tweaking fix range selection eeb2f98
  * feat: rename modify_range -> get_replace_range 54837df
* Sat Jan  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.16.1:
  * feat: add support for bash and php #639
  * Breaking change: fix: more strict meta var parsing 13ad32b
  * Breaking change: refactor: remove thrift language 26ecdf6
  * fix(deps): update dependency @swc/core to v1.3.102 9ca9711
* Sat Dec 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * feat: add language globs to findInFiles in napi #780
  * Breaking change: fix: rename MetaVar for better naming #805
  * refactor: reorgnanize napi file structure 93f8577
  * refactor: move file type related function out of lib 64e33a3
  * feat: handle FileOption in LangOption::infer 7bc3efe
* Mon Dec 18 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.15.1:
  * feat: support mutliple rules in -r and --inline-rules #786
  * refactor: unify run_worker and run_std_in #785
  * Breaking change: feat: --stdin now always awaits user input #791
  * feat: support --inline-rules option for sg scan #396
  * refactor: separate PathWorker and StdInWorker and Worker ef3d8ad
  * test: add test cases for sg scan ed35c71
  * fix: revert github action a2f22d8
* Sat Dec 16 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.15.0:
  * Breaking change: feat: reduce metavar_env string allocation e1ab015
  * Breaking change: fix: remove pattern as replacer f6e4293
  * Breaking change: feat: better metavar detection e1ab18a
* Tue Dec 12 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.14.4:
  * fix: use tempfile to remove vuln #765
  * chore(deps): update dependency typescript to v5.3.3 dbac17d
  * chore(deps): update dependency @napi-rs/cli to v2.17.0 f2d32be
  * chore(deps): update dependency prettier to v3.1.1 990f09b
* Mon Dec 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.14.3:
  * feat: add getTransformed in napi #551
  * fix: load custom languages in new command #751
  * chore(deps): update dependency ava to v6 496eb9d
  * feat: add support for Elixir 57edde1
  * feat: rename fixer to TemplateFix 5b53ce0
* Sun Dec 10 2023 Michael Vetter <mvetter@suse.com>
- Initial package of ast-grep 0.14.2 for openSUSE
